@@ -46,6 +46,14 @@ class LogPlayerPosition(Event):
         self.num_alive_players = self._data.get('numAlivePlayers')
 
 
+class LogWeaponFireCount(Event):
+
+    def from_dict(self):
+        self.character = objects.Character(self._data.get('character', {}))
+        self.weapon_id = self._data.get('weaponId')
+        self.fire_count = self._data.get('fireCount')
+
+
 class LogPlayerAttack(Event):
 
     def from_dict(self):
@@ -82,6 +90,14 @@ class LogPlayerKill(Event):
         self.distance = self._data.get('distance')
 
 
+class LogParachuteLanding(Event):
+
+    def from_dict(self):
+        super().from_dict()
+        self.character = objects.Character(self._data.get('character', {}))
+        self.distance = self._data.get('distance')
+
+
 class LogItem(Event):
 
     def from_dict(self):
@@ -127,6 +143,41 @@ class LogItemDetach(LogItemBundle):
     pass
 
 
+class LogItemPickupFromCarePackage(LogItemPickup):
+    pass
+
+
+class LogItemPickupFromLootBox(LogItemPickup):
+
+    def from_dict(self):
+        super().from_dict()
+        self.team_id = self._data.get('ownerTeamId')
+
+
+class LogHeal(Event):
+
+    def from_dict(self):
+        super().from_dict()
+        self.character = objects.Character(self._data.get('character', {}))
+        self.item = objects.Item(self._data.get('item', {}))
+        self.heal_amount = self._data.get('healAmount')
+
+
+class LogObjectDestroy(Event):
+
+    def from_dict(self):
+        super().from_dict()
+        self.character = objects.Character(self._data.get('character', {}))
+        self.object_type = self._data.get('objectType')
+
+
+class LogVaultStart(Event):
+
+    def from_dict(self):
+        super().from_dict()
+        self.character = objects.Character(self._data.get('character', {}))
+
+
 class LogVehicle(Event):
 
     def from_dict(self):
@@ -283,3 +334,10 @@ class LogPlayerRevive(Event):
         super().from_dict()
         self.reviver = objects.Character(self._data.get('reviver', {}))
         self.victim = objects.Character(self._data.get('victim', {}))
+
+
+class LogRedZoneEnded(Event):
+
+    def from_dict(self):
+        super().from_dict()
+        self.drivers = self._data.get('drivers', [])
